# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from xbim_flex.aim.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from xbim_flex.aim.model.application import Application
from xbim_flex.aim.model.assembly_diagnostics import AssemblyDiagnostics
from xbim_flex.aim.model.assembly_info import AssemblyInfo
from xbim_flex.aim.model.assembly_item import AssemblyItem
from xbim_flex.aim.model.asset import Asset
from xbim_flex.aim.model.asset_create import AssetCreate
from xbim_flex.aim.model.asset_edit import AssetEdit
from xbim_flex.aim.model.asset_segment import AssetSegment
from xbim_flex.aim.model.attribute_definition import AttributeDefinition
from xbim_flex.aim.model.attribute_definition_create import AttributeDefinitionCreate
from xbim_flex.aim.model.attribute_definition_edit import AttributeDefinitionEdit
from xbim_flex.aim.model.attribute_definition_entity import AttributeDefinitionEntity
from xbim_flex.aim.model.attribute_value import AttributeValue
from xbim_flex.aim.model.attribute_value_entity import AttributeValueEntity
from xbim_flex.aim.model.cell import Cell
from xbim_flex.aim.model.classification_node import ClassificationNode
from xbim_flex.aim.model.column_definition import ColumnDefinition
from xbim_flex.aim.model.complex_value_base import ComplexValueBase
from xbim_flex.aim.model.component import Component
from xbim_flex.aim.model.component_create import ComponentCreate
from xbim_flex.aim.model.component_edit import ComponentEdit
from xbim_flex.aim.model.component_info import ComponentInfo
from xbim_flex.aim.model.component_type import ComponentType
from xbim_flex.aim.model.component_type_info import ComponentTypeInfo
from xbim_flex.aim.model.contact import Contact
from xbim_flex.aim.model.contact_entity import ContactEntity
from xbim_flex.aim.model.contact_info import ContactInfo
from xbim_flex.aim.model.db_update import DbUpdate
from xbim_flex.aim.model.document import Document
from xbim_flex.aim.model.document_create import DocumentCreate
from xbim_flex.aim.model.document_edit import DocumentEdit
from xbim_flex.aim.model.document_info import DocumentInfo
from xbim_flex.aim.model.entity import Entity
from xbim_flex.aim.model.entity_base import EntityBase
from xbim_flex.aim.model.entity_contact import EntityContact
from xbim_flex.aim.model.entity_create import EntityCreate
from xbim_flex.aim.model.entity_edit import EntityEdit
from xbim_flex.aim.model.entity_mapping_info import EntityMappingInfo
from xbim_flex.aim.model.entity_match_descriptor import EntityMatchDescriptor
from xbim_flex.aim.model.entity_match_info import EntityMatchInfo
from xbim_flex.aim.model.entity_ref import EntityRef
from xbim_flex.aim.model.facility import Facility
from xbim_flex.aim.model.facility_info import FacilityInfo
from xbim_flex.aim.model.file_upload_result import FileUploadResult
from xbim_flex.aim.model.footprint import Footprint
from xbim_flex.aim.model.i_metered_resource import IMeteredResource
from xbim_flex.aim.model.ifc_type import IfcType
from xbim_flex.aim.model.inline_object import InlineObject
from xbim_flex.aim.model.inline_object1 import InlineObject1
from xbim_flex.aim.model.inline_object2 import InlineObject2
from xbim_flex.aim.model.inline_object3 import InlineObject3
from xbim_flex.aim.model.inline_object4 import InlineObject4
from xbim_flex.aim.model.inline_object5 import InlineObject5
from xbim_flex.aim.model.issue import Issue
from xbim_flex.aim.model.issue_info import IssueInfo
from xbim_flex.aim.model.job import Job
from xbim_flex.aim.model.job_create import JobCreate
from xbim_flex.aim.model.job_edit import JobEdit
from xbim_flex.aim.model.job_info import JobInfo
from xbim_flex.aim.model.level import Level
from xbim_flex.aim.model.level_create import LevelCreate
from xbim_flex.aim.model.level_edit import LevelEdit
from xbim_flex.aim.model.level_info import LevelInfo
from xbim_flex.aim.model.mapping_message_info import MappingMessageInfo
from xbim_flex.aim.model.mapping_properties import MappingProperties
from xbim_flex.aim.model.member_permission import MemberPermission
from xbim_flex.aim.model.member_role import MemberRole
from xbim_flex.aim.model.model import Model
from xbim_flex.aim.model.model_create import ModelCreate
from xbim_flex.aim.model.model_edit import ModelEdit
from xbim_flex.aim.model.model_info import ModelInfo
from xbim_flex.aim.model.model_mapping import ModelMapping
from xbim_flex.aim.model.model_mapping_report import ModelMappingReport
from xbim_flex.aim.model.o_data_list_response_of_application import ODataListResponseOfApplication
from xbim_flex.aim.model.o_data_list_response_of_assembly_diagnostics import ODataListResponseOfAssemblyDiagnostics
from xbim_flex.aim.model.o_data_list_response_of_assembly_item import ODataListResponseOfAssemblyItem
from xbim_flex.aim.model.o_data_list_response_of_asset import ODataListResponseOfAsset
from xbim_flex.aim.model.o_data_list_response_of_attribute_definition import ODataListResponseOfAttributeDefinition
from xbim_flex.aim.model.o_data_list_response_of_attribute_definition_entity import ODataListResponseOfAttributeDefinitionEntity
from xbim_flex.aim.model.o_data_list_response_of_attribute_value import ODataListResponseOfAttributeValue
from xbim_flex.aim.model.o_data_list_response_of_complex_value_base import ODataListResponseOfComplexValueBase
from xbim_flex.aim.model.o_data_list_response_of_component import ODataListResponseOfComponent
from xbim_flex.aim.model.o_data_list_response_of_component_type import ODataListResponseOfComponentType
from xbim_flex.aim.model.o_data_list_response_of_contact import ODataListResponseOfContact
from xbim_flex.aim.model.o_data_list_response_of_document import ODataListResponseOfDocument
from xbim_flex.aim.model.o_data_list_response_of_entity import ODataListResponseOfEntity
from xbim_flex.aim.model.o_data_list_response_of_entity_ref import ODataListResponseOfEntityRef
from xbim_flex.aim.model.o_data_list_response_of_facility import ODataListResponseOfFacility
from xbim_flex.aim.model.o_data_list_response_of_issue import ODataListResponseOfIssue
from xbim_flex.aim.model.o_data_list_response_of_job import ODataListResponseOfJob
from xbim_flex.aim.model.o_data_list_response_of_level import ODataListResponseOfLevel
from xbim_flex.aim.model.o_data_list_response_of_member_permission import ODataListResponseOfMemberPermission
from xbim_flex.aim.model.o_data_list_response_of_model import ODataListResponseOfModel
from xbim_flex.aim.model.o_data_list_response_of_model_mapping import ODataListResponseOfModelMapping
from xbim_flex.aim.model.o_data_list_response_of_model_mapping_report import ODataListResponseOfModelMappingReport
from xbim_flex.aim.model.o_data_list_response_of_resource import ODataListResponseOfResource
from xbim_flex.aim.model.o_data_list_response_of_role import ODataListResponseOfRole
from xbim_flex.aim.model.o_data_list_response_of_row import ODataListResponseOfRow
from xbim_flex.aim.model.o_data_list_response_of_schedule import ODataListResponseOfSchedule
from xbim_flex.aim.model.o_data_list_response_of_site import ODataListResponseOfSite
from xbim_flex.aim.model.o_data_list_response_of_space import ODataListResponseOfSpace
from xbim_flex.aim.model.o_data_list_response_of_spare import ODataListResponseOfSpare
from xbim_flex.aim.model.o_data_list_response_of_system_item import ODataListResponseOfSystemItem
from xbim_flex.aim.model.o_data_list_response_of_zone import ODataListResponseOfZone
from xbim_flex.aim.model.o_data_response_of_boolean import ODataResponseOfBoolean
from xbim_flex.aim.model.quota_status import QuotaStatus
from xbim_flex.aim.model.related_entity import RelatedEntity
from xbim_flex.aim.model.resource import Resource
from xbim_flex.aim.model.resource_info import ResourceInfo
from xbim_flex.aim.model.role import Role
from xbim_flex.aim.model.role_member import RoleMember
from xbim_flex.aim.model.row import Row
from xbim_flex.aim.model.schedule import Schedule
from xbim_flex.aim.model.site import Site
from xbim_flex.aim.model.space import Space
from xbim_flex.aim.model.space_create import SpaceCreate
from xbim_flex.aim.model.space_edit import SpaceEdit
from xbim_flex.aim.model.space_info import SpaceInfo
from xbim_flex.aim.model.spare import Spare
from xbim_flex.aim.model.spare_create import SpareCreate
from xbim_flex.aim.model.spare_edit import SpareEdit
from xbim_flex.aim.model.spare_info import SpareInfo
from xbim_flex.aim.model.system_info import SystemInfo
from xbim_flex.aim.model.system_item import SystemItem
from xbim_flex.aim.model.user_permissions import UserPermissions
from xbim_flex.aim.model.value_container import ValueContainer
from xbim_flex.aim.model.zone import Zone
from xbim_flex.aim.model.zone_info import ZoneInfo
