"""
    XBIM Flex API v1

    This is the XBIM Flex Swagger service where you can explore the REST API for the platform.  # noqa: E501

    The version of the OpenAPI document: v1
    Contact: info@xbim.net
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "xbim-flex"
VERSION = "1.0.2"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
  "urllib3 >= 1.25.3",
  "python-dateutil",
]

setup(
    name=NAME,
    version=VERSION,
    description="XBIM Flex API v1",
    author="XBIM Ltd",
    author_email="info@xbim.net",
    url = 'https://github.com/juliopereirab/xbim-flex-python', 
    download_url = 'https://github.com/juliopereirab/xbim-flex-python/archive/refs/tags/1.0.1.zip',
    keywords=["OpenAPI", "OpenAPI-Generator", "XBIM Flex API v1"],
    python_requires=">=3.6",
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description="""\
    This is the XBIM Flex Swagger service where you can explore the REST API for the platform.  # noqa: E501
    """
)
